'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.renderTable = exports.renderTitle = exports.renderRow = exports.renderWeek = exports.renderDay = undefined;

var _lodash = require('lodash.isarray');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns i18n day name, either abbreviated or full
 * @param  {object} opts - Options
 * @param  {number} day - Day of the week
 * @param  {boolean} abbr
 * @return {string}
 */
var renderDayName = function renderDayName(opts, day, abbr) {
    day += opts.firstDay;

    while (day >= 7) {
        day -= 7;
    }

    return abbr ? opts.i18n.weekdaysShort[day] : opts.i18n.weekdays[day];
};

/**
 * Returns <td> HTML for a day table cell
 * @param  {object} opts - Options
 * @return {string}
 */
var renderDay = exports.renderDay = function renderDay(opts) {
    if (opts.isEmpty) {
        return '<td class="is-empty"></td>';
    }

    var arr = [];

    if (opts.isDisabled) {
        arr.push('is-disabled');
    }

    if (opts.isToday) {
        arr.push('is-today');
    }

    if (opts.isSelected) {
        arr.push('is-selected');
    }

    if (opts.isInRange) {
        arr.push('is-inrange');
    }

    if (opts.isStartRange) {
        arr.push('is-startrange');
    }

    if (opts.isEndRange) {
        arr.push('is-endrange');
    }

    return '\n        <td data-day="' + opts.day + '" class="' + arr.join(' ') + '">\n            <button class="pika-button pika-day"\n                    type="button"\n                    data-pika-year="' + opts.year + '"\n                    data-pika-month="' + opts.month + '"\n                    data-pika-day="' + opts.day + '">\n                ' + opts.day + '\n            </button>\n        </td>\n    ';
};

/**
 * Returns <td> HTML for a week cell
 * @param  {number}
 * @param  {number}
 * @param  {number}
 * @return {string}
 *
 * Lifted from http://javascript.about.com/library/blweekyear.htm
 */
var renderWeek = exports.renderWeek = function renderWeek(d, m, y) {
    var onejan = new Date(y, 0, 1),
        weekNum = Math.ceil(((new Date(y, m, d) - onejan) / 86400000 + onejan.getDay() + 1) / 7);

    return '\n        <td class="pika-week">\n            ' + weekNum + '\n        </td>\n    ';
};

/**
 * Returns <tr> HTML for a day cells
 * @param  {string[]} days - Array of day strings
 * @param  {boolean} isRTL - Is right to left
 * @return {string}
 */
var renderRow = exports.renderRow = function renderRow(days, isRTL) {
    return '\n    <tr>\n        ' + (isRTL ? days.reverse() : days).join('') + '\n    </tr>\n';
};

/**
 * Returns the <thead> HTML for day names
 * @param  {object} opts - Options
 * @return {string}
 */
var renderHead = function renderHead(opts) {
    var i = undefined,
        arr = [];

    if (opts.showWeekNumber) {
        arr.push('<th></th>');
    }

    for (i = 0; i < 7; i++) {
        arr.push('\n            <th scope="col">\n                <abbr title="' + renderDayName(opts, i) + '">\n                    ' + renderDayName(opts, i, true) + '\n                </abbr>\n            </th>\n        ');
    }

    return '\n        <thead>\n            ' + (opts.isRTL ? arr.reverse() : arr).join('') + '\n        </thead>\n    ';
};

/**
 * Returns HTML for the title with select labels for years and months
 * @param  {object} opts - Options
 * @param  {number} nthCalendar - The nth calendar
 * @param  {number} year - The year
 * @param  {number} month
 * @param  {number} refYear - The year of the first calendar
 * @return {string}
 */
var renderTitle = exports.renderTitle = function renderTitle(opts, nthCalendar, year, month, refYear) {
    var i = undefined,
        j = undefined,
        arr = undefined,
        isMinYear = year === opts.minYear,
        isMaxYear = year === opts.maxYear,
        html = '<div class="pika-title">',
        monthHtml = undefined,
        yearHtml = undefined,
        prev = true,
        next = true;

    for (arr = [], i = 0; i < 12; i++) {
        arr.push('\n            <option value="' + (year === refYear ? i - nthCalendar : 12 + i - nthCalendar) + '"\n                    ' + (i === month ? ' selected' : '') + '\n                    ' + (isMinYear && i < opts.minMonth || isMaxYear && i > opts.maxMonth ? 'disabled' : '') + '>\n                ' + opts.i18n.months[i] + '\n            </option>\n        ');
    }

    monthHtml = '\n        <div class="pika-label">' + opts.i18n.months[month] + '\n            <select class="pika-select pika-select-month" tabindex="-1">\n                ' + arr.join('') + '\n            </select>\n        </div>\n    ';

    if ((0, _lodash2.default)(opts.yearRange)) {
        i = opts.yearRange[0];
        j = opts.yearRange[1] + 1;
    } else {
        i = year - opts.yearRange;
        j = 1 + year + opts.yearRange;
    }

    for (arr = []; i < j && i <= opts.maxYear; i++) {
        if (i >= opts.minYear) {
            arr.push('\n                <option value="' + i + '"\n                        ' + (i === year ? ' selected' : '') + '>\n                    ' + i + '\n                </option>\n            ');
        }
    }

    yearHtml = '\n        <div class="pika-label">' + (year + opts.yearSuffix) + '\n            <select class="pika-select pika-select-year" tabindex="-1">\n                ' + arr.join('') + '\n            </select>\n        </div>\n    ';

    if (opts.showMonthAfterYear) {
        html += yearHtml + monthHtml;
    } else {
        html += monthHtml + yearHtml;
    }

    if (isMinYear && (month === 0 || opts.minMonth >= month)) {
        prev = false;
    }

    if (isMaxYear && (month === 11 || opts.maxMonth <= month)) {
        next = false;
    }

    if (nthCalendar === 0) {
        html += '\n            <button class="pika-prev ' + (prev ? '' : ' is-disabled') + '" type="button">\n                ' + opts.i18n.previousMonth + '\n            </button>\n        ';
    }

    if (nthCalendar === opts.numberOfMonths - 1) {
        html += '\n            <button class="pika-next ' + (next ? '' : ' is-disabled') + '" type="button">\n                ' + opts.i18n.nextMonth + '\n            </button>\n        ';
    }

    return html += '</div>';
};

/**
 * Returns <table> HTML with table rows
 * @param  {object} opts - Options
 * @param  {string[]} rows - Array of row HTML
 * @return {string}
 */
var renderTable = exports.renderTable = function renderTable(opts, rows) {
    return '\n    <table cellpadding="0" cellspacing="0" class="pika-table">\n        ' + renderHead(opts) + '\n        <tbody>\n            ' + rows.join('') + '\n        </tbody>\n    </table>\n';
};